# TODO: test swine and rat alleles since those
# can be significantly different from other species we've implementeds

# Rat alleles:
# - RT1-Bb*u
# - RT1-Db1*a
# - RT1-DMa*a
# - RT1-9.5*f
# - RT1-M3-1*av1
